@@ -26,7 +26,7 @@
 #include <type_traits>
 
 // HIP API
-#include "hipcub/device/device_radix_sort.hpp"
+#include <hipcub/device/device_radix_sort.hpp>
 
 #ifndef DEFAULT_N
 const size_t DEFAULT_N = 1024 * 1024 * 32;
@@ -40,19 +40,10 @@ std::vector<Key> generate_keys(size_t size)
 {
     using key_type = Key;
 
-    if(std::is_floating_point<key_type>::value)
-    {
-        return benchmark_utils::get_random_data<key_type>(size,
-                                                          (key_type)-1000,
-                                                          (key_type) + 1000,
-                                                          size);
-    } else
-    {
-        return benchmark_utils::get_random_data<key_type>(size,
-                                                          std::numeric_limits<key_type>::min(),
-                                                          std::numeric_limits<key_type>::max(),
-                                                          size);
-    }
+    return benchmark_utils::get_random_data<key_type>(
+        size,
+        benchmark_utils::generate_limits<key_type>::min(),
+        benchmark_utils::generate_limits<key_type>::max());
 }
 
 template<bool Descending, class Key>
