@@ -29,13 +29,13 @@
 
 // hipCUB API
 #ifdef __HIP_PLATFORM_AMD__
-    #include "hipcub/backend/rocprim/util_ptx.hpp"
+    #include <hipcub/backend/rocprim/util_ptx.hpp>
 #elif defined(__HIP_PLATFORM_NVIDIA__)
-    #include "hipcub/config.hpp"
     #include <cub/util_ptx.cuh>
+    #include <hipcub/config.hpp>
 #endif
 
-#include "hipcub/tuple.hpp"
+#include <hipcub/tuple.hpp>
 
 #ifndef HIPCUB_CUB_API
     #define HIPCUB_WARP_THREADS_MACRO warpSize
