@@ -23,11 +23,11 @@
 #include "common_test_header.hpp"
 
 // hipcub API
-#include "hipcub/device/device_scan.hpp"
-#include "hipcub/iterator/constant_input_iterator.hpp"
-#include "hipcub/iterator/counting_input_iterator.hpp"
-#include "hipcub/iterator/transform_input_iterator.hpp"
-#include "hipcub/thread/thread_operators.hpp"
+#include <hipcub/device/device_scan.hpp>
+#include <hipcub/iterator/constant_input_iterator.hpp>
+#include <hipcub/iterator/counting_input_iterator.hpp>
+#include <hipcub/iterator/transform_input_iterator.hpp>
+#include <hipcub/thread/thread_operators.hpp>
 
 #include "single_index_iterator.hpp"
 #include "test_utils_bfloat16.hpp"
@@ -139,8 +139,7 @@ TYPED_TEST(HipcubDeviceScanTests, InclusiveScan)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType     = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     constexpr bool inplace = std::is_same<T, U>::value && std::is_same<acc_type, T>::value;
 
     // for non-associative operations in inclusive scan
@@ -332,8 +331,7 @@ TYPED_TEST(HipcubDeviceScanTests, InclusiveScanInit)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType     = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     constexpr bool inplace = std::is_same<T, U>::value && std::is_same<acc_type, T>::value;
 
     // for non-associative operations in inclusive scan
@@ -517,8 +515,7 @@ TYPED_TEST(HipcubDeviceScanTests, InclusiveScanByKey)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     // for non-associative operations in inclusive scan
     // intermediate results use the type of input iterator, then
     // as all conversions in the tests are to more precise types,
@@ -703,8 +700,7 @@ TYPED_TEST(HipcubDeviceScanTests, ExclusiveScan)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType     = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     constexpr bool inplace = std::is_same<T, U>::value && std::is_same<acc_type, T>::value;
 
     // for non-associative operations in inclusive scan
@@ -909,8 +905,7 @@ TYPED_TEST(HipcubDeviceScanTests, ExclusiveScanByKey)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     // for non-associative operations in inclusive scan
     // intermediate results use the type of input iterator, then
     // as all conversions in the tests are to more precise types,
@@ -1098,7 +1093,7 @@ TYPED_TEST(HipcubDeviceScanTests, ExclusiveScanByKey)
 TEST(HipcubDeviceScanTests, LargeIndicesInclusiveScan)
 {
     using T              = unsigned int;
-    using InputIterator  = typename hipcub::CountingInputIterator<T>;
+    using InputIterator  = rocprim::counting_iterator<T>;
     using OutputIterator = test_utils::single_index_iterator<T>;
 
     const size_t size = (1ul << 31) + 1ul;
@@ -1108,7 +1103,7 @@ TEST(HipcubDeviceScanTests, LargeIndicesInclusiveScan)
     unsigned int seed_value = rand();
     SCOPED_TRACE(testing::Message() << "with seed= " << seed_value);
 
-    // Create CountingInputIterator<U> with random starting point
+    // Create rocprim::counting_iterator<U> with random starting point
     InputIterator input_begin(test_utils::get_random_value<T>(0, 200, seed_value));
 
     T* d_output;
@@ -1168,7 +1163,7 @@ TEST(HipcubDeviceScanTests, LargeIndicesInclusiveScan)
 TEST(HipcubDeviceScanTests, LargeIndicesExclusiveScan)
 {
     using T              = unsigned int;
-    using InputIterator  = typename hipcub::CountingInputIterator<T>;
+    using InputIterator  = rocprim::counting_iterator<T>;
     using OutputIterator = test_utils::single_index_iterator<T>;
 
     const size_t size = (1ul << 31) + 1ul;
@@ -1178,7 +1173,7 @@ TEST(HipcubDeviceScanTests, LargeIndicesExclusiveScan)
     unsigned int seed_value = rand();
     SCOPED_TRACE(testing::Message() << "with seed= " << seed_value);
 
-    // Create CountingInputIterator<U> with random starting point
+    // Create rocprim::counting_iterator<U> with random starting point
     InputIterator input_begin(test_utils::get_random_value<T>(0, 200, seed_value));
     T             initial_value = test_utils::get_random_value<T>(1, 10, seed_value);
 
@@ -1263,8 +1258,7 @@ TYPED_TEST(HipcubDeviceScanTests, ExclusiveScanFuture)
     // use float as device-side accumulator and double as host-side accumulator
     using is_add_op    = test_utils::is_add_operator<scan_op_type>;
     using acc_type     = typename accum_type<T, scan_op_type>::type;
-    using IteratorType = hipcub::TransformInputIterator<acc_type, hipcub::CastOp<acc_type>, T*>;
-
+    using IteratorType = rocprim::transform_iterator<T*, hipcub::CastOp<acc_type>, acc_type>;
     // for non-associative operations in inclusive scan
     // intermediate results use the type of input iterator, then
     // as all conversions in the tests are to more precise types,
