@@ -27,11 +27,11 @@
  *
  ******************************************************************************/
 
-#include "hipcub/thread/thread_load.hpp"
-#include "hipcub/thread/thread_store.hpp"
-#include "hipcub/thread/thread_reduce.hpp"
-#include "hipcub/thread/thread_scan.hpp"
-#include "hipcub/thread/thread_search.hpp"
+#include <hipcub/thread/thread_load.hpp>
+#include <hipcub/thread/thread_reduce.hpp>
+#include <hipcub/thread/thread_scan.hpp>
+#include <hipcub/thread/thread_search.hpp>
+#include <hipcub/thread/thread_store.hpp>
 
 #include "test_utils_bfloat16.hpp"
 #include "test_utils_half.hpp"
@@ -106,9 +106,16 @@ void thread_load_kernel(Type* volatile const device_input, Type* device_output)
     }
     else // index % 8 == 7
     {
+        // TODO: For compatibility, should also change this API in rocm backend
+#ifdef __HIP_PLATFORM_NVIDIA__
         device_output[index] = hipcub::ThreadLoadVolatilePointer(
             device_input + index,
-            hipcub::Int2Type<std::is_fundamental<Type>::value>());
+            ::cuda::std::integral_constant<bool, std::is_fundamental<Type>::value>{});
+#else
+        device_output[index] = hipcub::ThreadLoadVolatilePointer(
+            device_input + index,
+            std::bool_constant<std::is_fundamental<Type>::value>());
+#endif
     }
 }
 
@@ -296,9 +303,17 @@ void thread_store_kernel(Type* const device_input, Type* device_output)
     }
     else // index % 7 == 6
     {
+        // TODO: For compatibility, should also change this API in rocm backend
+#ifdef __HIP_PLATFORM_NVIDIA__
+        hipcub::ThreadStoreVolatilePtr(
+            device_output + index,
+            device_input[index],
+            ::cuda::std::integral_constant<bool, std::is_fundamental<Type>::value>{});
+#else
         hipcub::ThreadStoreVolatilePtr(device_output + index,
                                        device_input[index],
-                                       hipcub::Int2Type<std::is_fundamental<Type>::value>());
+                                       std::bool_constant<std::is_fundamental<Type>::value>());
+#endif
     }
 }
 
@@ -380,14 +395,13 @@ void iterate_thread_kernel(Type* const device_input, Type* device_output)
 
     if(id % 2 == 0)
     {
-        hipcub::IterateThreadStore<0, ItemsPerThread>::Dereference(device_output + index,
-                                                                   device_input + index);
+        hipcub::detail::iterate_thread_store<0, ItemsPerThread>::Dereference(device_output + index,
+                                                                             device_input + index);
     }
     else
     {
-        hipcub::IterateThreadStore<0, ItemsPerThread>::template Store<hipcub::STORE_DEFAULT>(
-            device_output + index,
-            device_input + index);
+        hipcub::detail::iterate_thread_store<0, ItemsPerThread>::template Store<
+            hipcub::STORE_DEFAULT>(device_output + index, device_input + index);
     }
 }
 
@@ -467,7 +481,8 @@ void thread_reduce_kernel(Type* const device_input, Type* device_output)
 {
     size_t input_index = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x) * Length;
     size_t output_index = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x) * Length;
-    device_output[output_index] = hipcub::internal::ThreadReduce<Length>(&device_input[input_index], sum_op());
+    device_output[output_index]
+        = hipcub::ThreadReduce<Length>(&device_input[input_index], sum_op());
 }
 
 TYPED_TEST(HipcubThreadOperationTests, Reduction)
