@@ -740,8 +740,7 @@ TYPED_TEST(HipcubNCThreadOperatorsTests, CastOp)
     using input_type  = typename TestFixture::input_type;
     using output_type = typename TestFixture::output_type;
     using IteratorType
-        = hipcub::TransformInputIterator<output_type, hipcub::CastOp<output_type>, input_type*>;
-
+        = rocprim::transform_iterator<input_type*, hipcub::CastOp<output_type>, output_type>;
     const std::vector<size_t> sizes = get_sizes();
     for(auto input_size : sizes)
     {
